package sun.security.krb5;

import sun.security.krb5.internal.KrbApErrException;
import sun.security.util.DerValue;
import sun.security.krb5.internal.KdcErrException;
import sun.security.krb5.internal.EncKrbPrivPart;
import sun.security.krb5.internal.KRBPriv;
import java.io.IOException;
import sun.security.krb5.internal.HostAddress;
import sun.security.krb5.internal.SeqNumber;
import sun.security.krb5.internal.KerberosTime;

class KrbPriv extends KrbAppMessage
{
    private byte[] obuf;
    private byte[] userData;
    
    private KrbPriv(byte[] array, Credentials credentials, EncryptionKey encryptionKey, KerberosTime kerberosTime, SeqNumber seqNumber, HostAddress hostAddress, HostAddress hostAddress2) throws KrbException, IOException {
        EncryptionKey key;
        if (encryptionKey != null) {
            key = encryptionKey;
        }
        else {
            key = credentials.key;
        }
        this.obuf = this.mk_priv(array, key, kerberosTime, seqNumber, hostAddress, hostAddress2);
    }
    
    private KrbPriv(byte[] array, Credentials credentials, EncryptionKey encryptionKey, SeqNumber seqNumber, HostAddress hostAddress, HostAddress hostAddress2, boolean b, boolean b2) throws KrbException, IOException {
        KRBPriv krbPriv = new KRBPriv(array);
        EncryptionKey key;
        if (encryptionKey != null) {
            key = encryptionKey;
        }
        else {
            key = credentials.key;
        }
        this.userData = this.rd_priv(krbPriv, key, seqNumber, hostAddress, hostAddress2, b, b2, credentials.client);
    }
    
    public byte[] getMessage() throws KrbException {
        return this.obuf;
    }
    
    public byte[] getData() {
        return this.userData;
    }
    
    private byte[] mk_priv(byte[] array, EncryptionKey encryptionKey, KerberosTime kerberosTime, SeqNumber seqNumber, HostAddress hostAddress, HostAddress hostAddress2) throws Asn1Exception, IOException, KdcErrException, KrbCryptoException {
        Integer n = null;
        Object o = null;
        if (kerberosTime != null) {
            n = new Integer(kerberosTime.getMicroSeconds());
        }
        if (seqNumber != null) {
            o = new Integer(seqNumber.current());
            seqNumber.step();
        }
        KRBPriv o2 = new KRBPriv(new EncryptedData(encryptionKey, new EncKrbPrivPart(array, kerberosTime, n, o, hostAddress, hostAddress2).asn1Encode(), 13));
        o2.asn1Encode();
        return o2.asn1Encode();
    }
    
    private byte[] rd_priv(KRBPriv krbPriv, EncryptionKey encryptionKey, SeqNumber seqNumber, HostAddress hostAddress, HostAddress hostAddress2, boolean b, boolean b2, PrincipalName principalName) throws Asn1Exception, KdcErrException, KrbApErrException, IOException, KrbCryptoException {
        EncKrbPrivPart encKrbPrivPart = new EncKrbPrivPart(new DerValue(krbPriv.encPart.reset(krbPriv.encPart.decrypt(encryptionKey, 13))));
        this.check(encKrbPrivPart.timestamp, encKrbPrivPart.usec, encKrbPrivPart.seqNumber, encKrbPrivPart.sAddress, encKrbPrivPart.rAddress, seqNumber, hostAddress, hostAddress2, b, b2, principalName);
        return encKrbPrivPart.userData;
    }
}
